# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(artifact/artifact/v1alpha/artifact.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x96\x01\n\x0fLivenessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"v\n\x10LivenessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\x97\x01\n\x10ReadinessRequest\x12j\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x04\xe2\x41\x01\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"w\n\x11ReadinessResponse\x12\x62\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseR\x13healthCheckResponse\"\xa1\x01\n\rRepositoryTag\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x05R\x04name\x12\x14\n\x02id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1c\n\x06\x64igest\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x06\x64igest\x12\x42\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x01R\nupdateTime\"\xb7\x01\n\x19ListRepositoryTagsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12\x1d\n\x04page\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x04page\x88\x01\x01\x12<\n\x06parent\x18\x03 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1b\x61pi.instill.tech/RepositoryR\x06parentB\x0c\n\n_page_sizeB\x07\n\x05_page\"\xaa\x01\n\x1aListRepositoryTagsResponse\x12<\n\x04tags\x18\x01 \x03(\x0b\x32(.artifact.artifact.v1alpha.RepositoryTagR\x04tags\x12\x1d\n\ntotal_size\x18\x02 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x04 \x01(\x05R\x04page\"X\n\x1a\x43reateRepositoryTagRequest\x12:\n\x03tag\x18\x01 \x01(\x0b\x32(.artifact.artifact.v1alpha.RepositoryTagR\x03tag\"Y\n\x1b\x43reateRepositoryTagResponse\x12:\n\x03tag\x18\x01 \x01(\x0b\x32(.artifact.artifact.v1alpha.RepositoryTagR\x03tag\"3\n\x17GetRepositoryTagRequest\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\"V\n\x18GetRepositoryTagResponse\x12:\n\x03tag\x18\x01 \x01(\x0b\x32(.artifact.artifact.v1alpha.RepositoryTagR\x03tag\"6\n\x1a\x44\x65leteRepositoryTagRequest\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\"\x1d\n\x1b\x44\x65leteRepositoryTagResponse\"\xf4\x03\n\rKnowledgeBase\x12\x13\n\x05kb_id\x18\x01 \x01(\tR\x04kbId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1f\n\x0b\x63reate_time\x18\x05 \x01(\tR\ncreateTime\x12\x1f\n\x0bupdate_time\x18\x06 \x01(\tR\nupdateTime\x12\x1d\n\nowner_name\x18\x07 \x01(\tR\townerName\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12\x31\n\x14\x63onverting_pipelines\x18\t \x03(\tR\x13\x63onvertingPipelines\x12/\n\x13splitting_pipelines\x18\n \x03(\tR\x12splittingPipelines\x12/\n\x13\x65mbedding_pipelines\x18\x0b \x03(\tR\x12\x65mbeddingPipelines\x12\'\n\x0f\x64ownstream_apps\x18\x0c \x03(\tR\x0e\x64ownstreamApps\x12\x1f\n\x0btotal_files\x18\r \x01(\rR\ntotalFiles\x12!\n\x0ctotal_tokens\x18\x0e \x01(\rR\x0btotalTokens\x12!\n\x0cused_storage\x18\x0f \x01(\x04R\x0busedStorage\"\x89\x01\n\x1a\x43reateKnowledgeBaseRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04tags\x18\x04 \x03(\tR\x04tags\"n\n\x1b\x43reateKnowledgeBaseResponse\x12O\n\x0eknowledge_base\x18\x01 \x01(\x0b\x32(.artifact.artifact.v1alpha.KnowledgeBaseR\rknowledgeBase\">\n\x19ListKnowledgeBasesRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\"o\n\x1aListKnowledgeBasesResponse\x12Q\n\x0fknowledge_bases\x18\x01 \x03(\x0b\x32(.artifact.artifact.v1alpha.KnowledgeBaseR\x0eknowledgeBases\"\x8a\x01\n\x1aUpdateKnowledgeBaseRequest\x12\x13\n\x05kb_id\x18\x01 \x01(\tR\x04kbId\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12!\n\x0cnamespace_id\x18\x04 \x01(\tR\x0bnamespaceId\"n\n\x1bUpdateKnowledgeBaseResponse\x12O\n\x0eknowledge_base\x18\x01 \x01(\x0b\x32(.artifact.artifact.v1alpha.KnowledgeBaseR\rknowledgeBase\"T\n\x1a\x44\x65leteKnowledgeBaseRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x13\n\x05kb_id\x18\x02 \x01(\tR\x04kbId\"n\n\x1b\x44\x65leteKnowledgeBaseResponse\x12O\n\x0eknowledge_base\x18\x01 \x01(\x0b\x32(.artifact.artifact.v1alpha.KnowledgeBaseR\rknowledgeBase\"\xee\x05\n\x04\x46ile\x12\x1f\n\x08\x66ile_uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x66ileUid\x12\x18\n\x04name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\x12=\n\x04type\x18\x03 \x01(\x0e\x32#.artifact.artifact.v1alpha.FileTypeB\x04\xe2\x41\x01\x02R\x04type\x12Y\n\x0eprocess_status\x18\x04 \x01(\x0e\x32,.artifact.artifact.v1alpha.FileProcessStatusB\x04\xe2\x41\x01\x03R\rprocessStatus\x12-\n\x0fprocess_outcome\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x0eprocessOutcome\x12&\n\x0bretrievable\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x0bretrievable\x12\x1e\n\x07\x63ontent\x18\x07 \x01(\tB\x04\xe2\x41\x01\x01R\x07\x63ontent\x12!\n\towner_uid\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x08ownerUid\x12%\n\x0b\x63reator_uid\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\ncreatorUid\x12\x1b\n\x06kb_uid\x18\n \x01(\tB\x04\xe2\x41\x01\x03R\x05kbUid\x12\x41\n\x0b\x63reate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x41\n\x0b\x64\x65lete_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ndeleteTime\x12\x18\n\x04size\x18\x0e \x01(\x03\x42\x04\xe2\x41\x01\x03R\x04size\x12\'\n\x0ctotal_chunks\x18\x0f \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0btotalChunks\x12\'\n\x0ctotal_tokens\x18\x10 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0btotalTokens\"\x99\x01\n\x1eUploadKnowledgeBaseFileRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x19\n\x05kb_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x04kbId\x12\x33\n\x04\x66ile\x18\x03 \x01(\x0b\x32\x1f.artifact.artifact.v1alpha.FileR\x04\x66ile\"V\n\x1fUploadKnowledgeBaseFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.artifact.artifact.v1alpha.FileR\x04\x66ile\"A\n\x1e\x44\x65leteKnowledgeBaseFileRequest\x12\x1f\n\x08\x66ile_uid\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x07\x66ileUid\"<\n\x1f\x44\x65leteKnowledgeBaseFileResponse\x12\x19\n\x08\x66ile_uid\x18\x01 \x01(\tR\x07\x66ileUid\"E\n ProcessKnowledgeBaseFilesRequest\x12!\n\tfile_uids\x18\x01 \x03(\tB\x04\xe2\x41\x01\x02R\x08\x66ileUids\"Z\n!ProcessKnowledgeBaseFilesResponse\x12\x35\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.artifact.artifact.v1alpha.FileR\x05\x66iles\"A\n\x1cListKnowledgeBaseFilesFilter\x12!\n\tfile_uids\x18\x02 \x03(\tB\x04\xe2\x41\x01\x01R\x08\x66ileUids\"\xf6\x01\n\x1dListKnowledgeBaseFilesRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x13\n\x05kb_id\x18\x02 \x01(\tR\x04kbId\x12!\n\tpage_size\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\x12U\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x37.artifact.artifact.v1alpha.ListKnowledgeBaseFilesFilterB\x04\xe2\x41\x01\x01R\x06\x66ilter\"\x8c\x02\n\x1eListKnowledgeBaseFilesResponse\x12\x35\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.artifact.artifact.v1alpha.FileR\x05\x66iles\x12\x1d\n\ntotal_size\x18\x02 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12&\n\x0fnext_page_token\x18\x04 \x01(\tR\rnextPageToken\x12O\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x37.artifact.artifact.v1alpha.ListKnowledgeBaseFilesFilterR\x06\x66ilter*\xa9\x02\n\x11\x46ileProcessStatus\x12#\n\x1f\x46ILE_PROCESS_STATUS_UNSPECIFIED\x10\x00\x12\"\n\x1e\x46ILE_PROCESS_STATUS_NOTSTARTED\x10\x01\x12\x1f\n\x1b\x46ILE_PROCESS_STATUS_WAITING\x10\x02\x12\"\n\x1e\x46ILE_PROCESS_STATUS_CONVERTING\x10\x03\x12 \n\x1c\x46ILE_PROCESS_STATUS_CHUNKING\x10\x04\x12!\n\x1d\x46ILE_PROCESS_STATUS_EMBEDDING\x10\x05\x12!\n\x1d\x46ILE_PROCESS_STATUS_COMPLETED\x10\x06\x12\x1e\n\x1a\x46ILE_PROCESS_STATUS_FAILED\x10\x07*\x9e\x01\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46ILE_TYPE_TEXT\x10\x01\x12\x11\n\rFILE_TYPE_PDF\x10\x02\x12\x16\n\x12\x46ILE_TYPE_MARKDOWN\x10\x03\x12\x11\n\rFILE_TYPE_PNG\x10\x04\x12\x12\n\x0e\x46ILE_TYPE_JPEG\x10\x05\x12\x11\n\rFILE_TYPE_JPG\x10\x06\x42\x81\x02\n\x1d\x63om.artifact.artifact.v1alphaB\rArtifactProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\rArtifactProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\342A\001\001'
  _REPOSITORYTAG.fields_by_name['name']._options = None
  _REPOSITORYTAG.fields_by_name['name']._serialized_options = b'\342A\001\005'
  _REPOSITORYTAG.fields_by_name['id']._options = None
  _REPOSITORYTAG.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _REPOSITORYTAG.fields_by_name['digest']._options = None
  _REPOSITORYTAG.fields_by_name['digest']._serialized_options = b'\342A\001\001'
  _REPOSITORYTAG.fields_by_name['update_time']._options = None
  _REPOSITORYTAG.fields_by_name['update_time']._serialized_options = b'\342A\002\003\001'
  _LISTREPOSITORYTAGSREQUEST.fields_by_name['page_size']._options = None
  _LISTREPOSITORYTAGSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTREPOSITORYTAGSREQUEST.fields_by_name['page']._options = None
  _LISTREPOSITORYTAGSREQUEST.fields_by_name['page']._serialized_options = b'\342A\001\001'
  _LISTREPOSITORYTAGSREQUEST.fields_by_name['parent']._options = None
  _LISTREPOSITORYTAGSREQUEST.fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\035\n\033api.instill.tech/Repository'
  _GETREPOSITORYTAGREQUEST.fields_by_name['name']._options = None
  _GETREPOSITORYTAGREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _DELETEREPOSITORYTAGREQUEST.fields_by_name['name']._options = None
  _DELETEREPOSITORYTAGREQUEST.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _FILE.fields_by_name['file_uid']._options = None
  _FILE.fields_by_name['file_uid']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['name']._options = None
  _FILE.fields_by_name['name']._serialized_options = b'\342A\001\002'
  _FILE.fields_by_name['type']._options = None
  _FILE.fields_by_name['type']._serialized_options = b'\342A\001\002'
  _FILE.fields_by_name['process_status']._options = None
  _FILE.fields_by_name['process_status']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['process_outcome']._options = None
  _FILE.fields_by_name['process_outcome']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['retrievable']._options = None
  _FILE.fields_by_name['retrievable']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['content']._options = None
  _FILE.fields_by_name['content']._serialized_options = b'\342A\001\001'
  _FILE.fields_by_name['owner_uid']._options = None
  _FILE.fields_by_name['owner_uid']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['creator_uid']._options = None
  _FILE.fields_by_name['creator_uid']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['kb_uid']._options = None
  _FILE.fields_by_name['kb_uid']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['create_time']._options = None
  _FILE.fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['update_time']._options = None
  _FILE.fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['delete_time']._options = None
  _FILE.fields_by_name['delete_time']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['size']._options = None
  _FILE.fields_by_name['size']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['total_chunks']._options = None
  _FILE.fields_by_name['total_chunks']._serialized_options = b'\342A\001\003'
  _FILE.fields_by_name['total_tokens']._options = None
  _FILE.fields_by_name['total_tokens']._serialized_options = b'\342A\001\003'
  _UPLOADKNOWLEDGEBASEFILEREQUEST.fields_by_name['namespace_id']._options = None
  _UPLOADKNOWLEDGEBASEFILEREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _UPLOADKNOWLEDGEBASEFILEREQUEST.fields_by_name['kb_id']._options = None
  _UPLOADKNOWLEDGEBASEFILEREQUEST.fields_by_name['kb_id']._serialized_options = b'\342A\001\002'
  _DELETEKNOWLEDGEBASEFILEREQUEST.fields_by_name['file_uid']._options = None
  _DELETEKNOWLEDGEBASEFILEREQUEST.fields_by_name['file_uid']._serialized_options = b'\342A\001\002'
  _PROCESSKNOWLEDGEBASEFILESREQUEST.fields_by_name['file_uids']._options = None
  _PROCESSKNOWLEDGEBASEFILESREQUEST.fields_by_name['file_uids']._serialized_options = b'\342A\001\002'
  _LISTKNOWLEDGEBASEFILESFILTER.fields_by_name['file_uids']._options = None
  _LISTKNOWLEDGEBASEFILESFILTER.fields_by_name['file_uids']._serialized_options = b'\342A\001\001'
  _LISTKNOWLEDGEBASEFILESREQUEST.fields_by_name['page_size']._options = None
  _LISTKNOWLEDGEBASEFILESREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTKNOWLEDGEBASEFILESREQUEST.fields_by_name['page_token']._options = None
  _LISTKNOWLEDGEBASEFILESREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTKNOWLEDGEBASEFILESREQUEST.fields_by_name['filter']._options = None
  _LISTKNOWLEDGEBASEFILESREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_FILEPROCESSSTATUS']._serialized_start=4949
  _globals['_FILEPROCESSSTATUS']._serialized_end=5246
  _globals['_FILETYPE']._serialized_start=5249
  _globals['_FILETYPE']._serialized_end=5407
  _globals['_LIVENESSREQUEST']._serialized_start=210
  _globals['_LIVENESSREQUEST']._serialized_end=360
  _globals['_LIVENESSRESPONSE']._serialized_start=362
  _globals['_LIVENESSRESPONSE']._serialized_end=480
  _globals['_READINESSREQUEST']._serialized_start=483
  _globals['_READINESSREQUEST']._serialized_end=634
  _globals['_READINESSRESPONSE']._serialized_start=636
  _globals['_READINESSRESPONSE']._serialized_end=755
  _globals['_REPOSITORYTAG']._serialized_start=758
  _globals['_REPOSITORYTAG']._serialized_end=919
  _globals['_LISTREPOSITORYTAGSREQUEST']._serialized_start=922
  _globals['_LISTREPOSITORYTAGSREQUEST']._serialized_end=1105
  _globals['_LISTREPOSITORYTAGSRESPONSE']._serialized_start=1108
  _globals['_LISTREPOSITORYTAGSRESPONSE']._serialized_end=1278
  _globals['_CREATEREPOSITORYTAGREQUEST']._serialized_start=1280
  _globals['_CREATEREPOSITORYTAGREQUEST']._serialized_end=1368
  _globals['_CREATEREPOSITORYTAGRESPONSE']._serialized_start=1370
  _globals['_CREATEREPOSITORYTAGRESPONSE']._serialized_end=1459
  _globals['_GETREPOSITORYTAGREQUEST']._serialized_start=1461
  _globals['_GETREPOSITORYTAGREQUEST']._serialized_end=1512
  _globals['_GETREPOSITORYTAGRESPONSE']._serialized_start=1514
  _globals['_GETREPOSITORYTAGRESPONSE']._serialized_end=1600
  _globals['_DELETEREPOSITORYTAGREQUEST']._serialized_start=1602
  _globals['_DELETEREPOSITORYTAGREQUEST']._serialized_end=1656
  _globals['_DELETEREPOSITORYTAGRESPONSE']._serialized_start=1658
  _globals['_DELETEREPOSITORYTAGRESPONSE']._serialized_end=1687
  _globals['_KNOWLEDGEBASE']._serialized_start=1690
  _globals['_KNOWLEDGEBASE']._serialized_end=2190
  _globals['_CREATEKNOWLEDGEBASEREQUEST']._serialized_start=2193
  _globals['_CREATEKNOWLEDGEBASEREQUEST']._serialized_end=2330
  _globals['_CREATEKNOWLEDGEBASERESPONSE']._serialized_start=2332
  _globals['_CREATEKNOWLEDGEBASERESPONSE']._serialized_end=2442
  _globals['_LISTKNOWLEDGEBASESREQUEST']._serialized_start=2444
  _globals['_LISTKNOWLEDGEBASESREQUEST']._serialized_end=2506
  _globals['_LISTKNOWLEDGEBASESRESPONSE']._serialized_start=2508
  _globals['_LISTKNOWLEDGEBASESRESPONSE']._serialized_end=2619
  _globals['_UPDATEKNOWLEDGEBASEREQUEST']._serialized_start=2622
  _globals['_UPDATEKNOWLEDGEBASEREQUEST']._serialized_end=2760
  _globals['_UPDATEKNOWLEDGEBASERESPONSE']._serialized_start=2762
  _globals['_UPDATEKNOWLEDGEBASERESPONSE']._serialized_end=2872
  _globals['_DELETEKNOWLEDGEBASEREQUEST']._serialized_start=2874
  _globals['_DELETEKNOWLEDGEBASEREQUEST']._serialized_end=2958
  _globals['_DELETEKNOWLEDGEBASERESPONSE']._serialized_start=2960
  _globals['_DELETEKNOWLEDGEBASERESPONSE']._serialized_end=3070
  _globals['_FILE']._serialized_start=3073
  _globals['_FILE']._serialized_end=3823
  _globals['_UPLOADKNOWLEDGEBASEFILEREQUEST']._serialized_start=3826
  _globals['_UPLOADKNOWLEDGEBASEFILEREQUEST']._serialized_end=3979
  _globals['_UPLOADKNOWLEDGEBASEFILERESPONSE']._serialized_start=3981
  _globals['_UPLOADKNOWLEDGEBASEFILERESPONSE']._serialized_end=4067
  _globals['_DELETEKNOWLEDGEBASEFILEREQUEST']._serialized_start=4069
  _globals['_DELETEKNOWLEDGEBASEFILEREQUEST']._serialized_end=4134
  _globals['_DELETEKNOWLEDGEBASEFILERESPONSE']._serialized_start=4136
  _globals['_DELETEKNOWLEDGEBASEFILERESPONSE']._serialized_end=4196
  _globals['_PROCESSKNOWLEDGEBASEFILESREQUEST']._serialized_start=4198
  _globals['_PROCESSKNOWLEDGEBASEFILESREQUEST']._serialized_end=4267
  _globals['_PROCESSKNOWLEDGEBASEFILESRESPONSE']._serialized_start=4269
  _globals['_PROCESSKNOWLEDGEBASEFILESRESPONSE']._serialized_end=4359
  _globals['_LISTKNOWLEDGEBASEFILESFILTER']._serialized_start=4361
  _globals['_LISTKNOWLEDGEBASEFILESFILTER']._serialized_end=4426
  _globals['_LISTKNOWLEDGEBASEFILESREQUEST']._serialized_start=4429
  _globals['_LISTKNOWLEDGEBASEFILESREQUEST']._serialized_end=4675
  _globals['_LISTKNOWLEDGEBASEFILESRESPONSE']._serialized_start=4678
  _globals['_LISTKNOWLEDGEBASEFILESRESPONSE']._serialized_end=4946
# @@protoc_insertion_point(module_scope)



import os
from enum import Enum
from typing import Any, Dict, List, Union

import numpy as np


class DataType(Enum):
    TYPE_BOOL = 1
    TYPE_UINT8 = 2
    TYPE_UINT16 = 3
    TYPE_UINT32 = 4
    TYPE_UINT64 = 5
    TYPE_INT8 = 6
    TYPE_INT16 = 7
    TYPE_INT32 = 8
    TYPE_INT64 = 9
    TYPE_FP16 = 10
    TYPE_FP32 = 11
    TYPE_FP64 = 12
    TYPE_STRING = 13


class TextGenerationInput:
    prompt = ""
    prompt_images: Union[List[np.ndarray], None] = None
    chat_history: Union[List[str], None] = None
    system_message: Union[str, None] = None
    max_new_tokens = 100
    temperature = 0.8
    top_k = 1
    random_seed = 0
    stop_words: Any = ""  # Optional
    extra_params: Dict[str, str] = {}


class TextToImageInput:
    prompt_image: Union[np.ndarray, None] = None
    prompt = ""
    negative_prompt = ""
    steps = 5
    guidance_scale = 7.5
    seed = 0
    samples = 1
    extra_params: Dict[str, str] = {}


class ImageToImageInput:
    prompt_image: Union[np.ndarray, None] = None
    prompt = ""
    steps = 5
    guidance_scale = 7.5
    seed = 0
    samples = 1
    extra_params: Dict[str, str] = {}


class TextGenerationChatInput:
    prompt = ""
    prompt_images: Union[List[np.ndarray], None] = None
    chat_history: Union[List[str], None] = None
    system_message: Union[str, None] = None
    max_new_tokens = 100
    temperature = 0.8
    top_k = 1
    random_seed = 0
    stop_words: Any = ""  # Optional
    extra_params: Dict[str, str] = {}


class VisualQuestionAnsweringInput:
    prompt = ""
    prompt_images: Union[List[np.ndarray], None] = None
    chat_history: Union[List[str], None] = None
    system_message: Union[str, None] = None
    max_new_tokens = 100
    temperature = 0.8
    top_k = 1
    random_seed = 0
    stop_words: Any = ""  # Optional
    extra_params: Dict[str, str] = {}


DEFAULT_RAY_ACTOR_OPTIONS = {
    "num_cpus": 0,
}
DEFAULT_AUTOSCALING_CONFIG = {
    "target_ongoing_requests": 2,
    "initial_replicas": 1,
    "min_replicas": 0,
    "max_replicas": 1,
    "upscale_delay_s": 600,
    "downscale_delay_s": 1800,
    "smoothing_factor": 1.0,
    "upscaling_factor": 0.8,
    "downscaling_factor": 0.8,
    "metrics_interval_s": 2,
    "look_back_period_s": 4,
}
DEFAULT_RUNTIME_ENV = {
    "env_vars": {
        "PYTHONPATH": os.getcwd(),
    },
}
DEFAULT_MAX_ONGOING_REQUESTS = 5
DEFAULT_MAX_QUEUED_REQUESTS = 10

RAM_MINIMUM_RESERVE = 1  # GB
RAM_UPSCALE_FACTOR = 1.25
VRAM_MINIMUM_RESERVE = 2  # GB
VRAM_UPSCALE_FACTOR = 1.25

DEFAULT_DEPENDENCIES = ["protobuf==4.25.3", "grpcio-tools==1.62.0"]

ENV_MEMORY = "RAY_MEMORY"
ENV_TOTAL_VRAM = "RAY_TOTAL_VRAM"
ENV_RAY_ACCELERATOR_TYPE = "RAY_ACCELERATOR_TYPE"
ENV_RAY_CUSTOM_RESOURCE = "RAY_CUSTOM_RESOURCE"
ENV_NUM_OF_GPUS = "RAY_NUM_OF_GPUS"
ENV_NUM_OF_CPUS = "RAY_NUM_OF_CPUS"
ENV_NUM_OF_MIN_REPLICAS = "RAY_NUM_OF_MIN_REPLICAS"
ENV_NUM_OF_MAX_REPLICAS = "RAY_NUM_OF_MAX_REPLICAS"
ENV_IS_TEST_MODEL = "RAY_IS_TEST_MODEL"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n model/model/v1alpha/common.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\"y\n\x0b\x42oundingBox\x12\x16\n\x03top\x18\x01 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x03top\x12\x18\n\x04left\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x04left\x12\x1a\n\x05width\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05width\x12\x1c\n\x06height\x18\x04 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x06height\"s\n\x0bPromptImage\x12*\n\x10prompt_image_url\x18\x01 \x01(\tH\x00R\x0epromptImageUrl\x12\x30\n\x13prompt_image_base64\x18\x02 \x01(\tH\x00R\x11promptImageBase64B\x06\n\x04type\"u\n\x0cImageContent\x12=\n\timage_url\x18\x01 \x01(\x0b\x32 .model.model.v1alpha.PromptImageR\x08imageUrl\x12\x1b\n\x06\x64\x65tail\x18\x02 \x01(\tH\x00R\x06\x64\x65tail\x88\x01\x01\x42\t\n\x07_detail\"\x87\x01\n\x0eMessageContent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12@\n\timage_url\x18\x02 \x01(\x0b\x32!.model.model.v1alpha.ImageContentH\x00R\x08imageUrl\x12\x14\n\x04text\x18\x03 \x01(\tH\x00R\x04textB\t\n\x07\x63ontent\"\\\n\x07Message\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12=\n\x07\x63ontent\x18\x02 \x03(\x0b\x32#.model.model.v1alpha.MessageContentR\x07\x63ontent\"H\n\nPermission\x12\x19\n\x08\x63\x61n_edit\x18\x01 \x01(\x08R\x07\x63\x61nEdit\x12\x1f\n\x0b\x63\x61n_trigger\x18\x02 \x01(\x08R\ncanTriggerB\xd8\x01\n\x17\x63om.model.model.v1alphaB\x0b\x43ommonProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\013CommonProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _BOUNDINGBOX.fields_by_name['top']._options = None
  _BOUNDINGBOX.fields_by_name['top']._serialized_options = b'\342A\001\003'
  _BOUNDINGBOX.fields_by_name['left']._options = None
  _BOUNDINGBOX.fields_by_name['left']._serialized_options = b'\342A\001\003'
  _BOUNDINGBOX.fields_by_name['width']._options = None
  _BOUNDINGBOX.fields_by_name['width']._serialized_options = b'\342A\001\003'
  _BOUNDINGBOX.fields_by_name['height']._options = None
  _BOUNDINGBOX.fields_by_name['height']._serialized_options = b'\342A\001\003'
  _globals['_BOUNDINGBOX']._serialized_start=90
  _globals['_BOUNDINGBOX']._serialized_end=211
  _globals['_PROMPTIMAGE']._serialized_start=213
  _globals['_PROMPTIMAGE']._serialized_end=328
  _globals['_IMAGECONTENT']._serialized_start=330
  _globals['_IMAGECONTENT']._serialized_end=447
  _globals['_MESSAGECONTENT']._serialized_start=450
  _globals['_MESSAGECONTENT']._serialized_end=585
  _globals['_MESSAGE']._serialized_start=587
  _globals['_MESSAGE']._serialized_end=679
  _globals['_PERMISSION']._serialized_start=681
  _globals['_PERMISSION']._serialized_end=753
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import artifact.artifact.v1alpha.artifact_pb2
import collections.abc
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class ArtifactPrivateServiceStub:
    """ArtifactPrivateService exposes the private endpoints that allow clients to
    manage artifacts.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListRepositoryTags: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsResponse,
    ]
    """List the tags in a repository.

    Returns a portion of the versions that the specified repository holds.
    """
    GetRepositoryTag: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagRequest,
        artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagResponse,
    ]
    """Get details of repository tag."""
    CreateRepositoryTag: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagRequest,
        artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagResponse,
    ]
    """Create a new repository tag.

    Adds a tag to a given repository. Note that this operation is only
    intended to register the information of an *already created* tag. This
    method should be called as part of the content push operation, right after
    the [PUT Manifest](https://distribution.github.io/distribution/#put-manifest) has
    succeeded. The distribution registry won't hold data such as the push time
    or the tag digest, so `artifact-backend` will hold this information locally.
    """
    DeleteRepositoryTag: grpc.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagResponse,
    ]
    """Delete a repository tag."""

class ArtifactPrivateServiceAsyncStub:
    """ArtifactPrivateService exposes the private endpoints that allow clients to
    manage artifacts.
    """

    ListRepositoryTags: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsRequest,
        artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsResponse,
    ]
    """List the tags in a repository.

    Returns a portion of the versions that the specified repository holds.
    """
    GetRepositoryTag: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagRequest,
        artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagResponse,
    ]
    """Get details of repository tag."""
    CreateRepositoryTag: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagRequest,
        artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagResponse,
    ]
    """Create a new repository tag.

    Adds a tag to a given repository. Note that this operation is only
    intended to register the information of an *already created* tag. This
    method should be called as part of the content push operation, right after
    the [PUT Manifest](https://distribution.github.io/distribution/#put-manifest) has
    succeeded. The distribution registry won't hold data such as the push time
    or the tag digest, so `artifact-backend` will hold this information locally.
    """
    DeleteRepositoryTag: grpc.aio.UnaryUnaryMultiCallable[
        artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagRequest,
        artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagResponse,
    ]
    """Delete a repository tag."""

class ArtifactPrivateServiceServicer(metaclass=abc.ABCMeta):
    """ArtifactPrivateService exposes the private endpoints that allow clients to
    manage artifacts.
    """

    @abc.abstractmethod
    def ListRepositoryTags(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.ListRepositoryTagsResponse]]:
        """List the tags in a repository.

        Returns a portion of the versions that the specified repository holds.
        """
    @abc.abstractmethod
    def GetRepositoryTag(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.GetRepositoryTagResponse]]:
        """Get details of repository tag."""
    @abc.abstractmethod
    def CreateRepositoryTag(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.CreateRepositoryTagResponse]]:
        """Create a new repository tag.

        Adds a tag to a given repository. Note that this operation is only
        intended to register the information of an *already created* tag. This
        method should be called as part of the content push operation, right after
        the [PUT Manifest](https://distribution.github.io/distribution/#put-manifest) has
        succeeded. The distribution registry won't hold data such as the push time
        or the tag digest, so `artifact-backend` will hold this information locally.
        """
    @abc.abstractmethod
    def DeleteRepositoryTag(
        self,
        request: artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagRequest,
        context: _ServicerContext,
    ) -> typing.Union[artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagResponse, collections.abc.Awaitable[artifact.artifact.v1alpha.artifact_pb2.DeleteRepositoryTagResponse]]:
        """Delete a repository tag."""

def add_ArtifactPrivateServiceServicer_to_server(servicer: ArtifactPrivateServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/component_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import common_pb2 as vdp_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.vdp/pipeline/v1beta/component_definition.proto\x12\x13vdp.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a vdp/pipeline/v1beta/common.proto\"\xf0\n\n\x13\x43omponentDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12G\n\x04spec\x18\x07 \x01(\x0b\x32-.vdp.pipeline.v1beta.ComponentDefinition.SpecB\x04\xe2\x41\x01\x03R\x04spec\x12<\n\x04type\x18\x08 \x01(\x0e\x32\".vdp.pipeline.v1beta.ComponentTypeB\x04\xe2\x41\x01\x03R\x04type\x12\"\n\ttombstone\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x1c\n\x06public\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06public\x12\x1c\n\x06\x63ustom\x18\x0b \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x63ustom\x12\x1c\n\x06vendor\x18\x0c \x01(\tB\x04\xe2\x41\x01\x03R\x06vendor\x12J\n\x11vendor_attributes\x18\r \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x10vendorAttributes\x12#\n\nsource_url\x18\x0e \x01(\tB\x04\xe2\x41\x01\x03R\tsourceUrl\x12\x1e\n\x07version\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\x07version\x12>\n\x05tasks\x18\x10 \x03(\x0b\x32\".vdp.pipeline.v1beta.ComponentTaskB\x04\xe2\x41\x01\x03R\x05tasks\x12&\n\x0b\x64\x65scription\x18\x11 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12`\n\rrelease_stage\x18\x12 \x01(\x0e\x32\x35.vdp.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage\x1a\xcb\x02\n\x04Spec\x12V\n\x17\x63omponent_specification\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x16\x63omponentSpecification\x12|\n\x13\x64\x61ta_specifications\x18\x05 \x03(\x0b\x32\x45.vdp.pipeline.v1beta.ComponentDefinition.Spec.DataSpecificationsEntryB\x04\xe2\x41\x01\x02R\x12\x64\x61taSpecifications\x1am\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12<\n\x05value\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01\";\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\"\xbc\x01\n\x0cReleaseStage\x12\x1d\n\x19RELEASE_STAGE_UNSPECIFIED\x10\x00\x12\'\n#RELEASE_STAGE_OPEN_FOR_CONTRIBUTION\x10\x01\x12\x1d\n\x19RELEASE_STAGE_COMING_SOON\x10\x02\x12\x17\n\x13RELEASE_STAGE_ALPHA\x10\x03\x12\x16\n\x12RELEASE_STAGE_BETA\x10\x04\x12\x14\n\x10RELEASE_STAGE_GA\x10\x05\"\x7f\n\x11\x44\x61taSpecification\x12\x33\n\x05input\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x05input\x12\x35\n\x06output\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x06output\"\xd5\x02\n\rConnectorSpec\x12V\n\x17\x63omponent_specification\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x16\x63omponentSpecification\x12q\n\x13\x64\x61ta_specifications\x18\x05 \x03(\x0b\x32:.vdp.pipeline.v1beta.ConnectorSpec.DataSpecificationsEntryB\x04\xe2\x41\x01\x02R\x12\x64\x61taSpecifications\x1am\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12<\n\x05value\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01J\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05\"\x85\x07\n\x13\x43onnectorDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12<\n\x04spec\x18\x07 \x01(\x0b\x32\".vdp.pipeline.v1beta.ConnectorSpecB\x04\xe2\x41\x01\x03R\x04spec\x12<\n\x04type\x18\x08 \x01(\x0e\x32\".vdp.pipeline.v1beta.ConnectorTypeB\x04\xe2\x41\x01\x03R\x04type\x12\"\n\ttombstone\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x1c\n\x06public\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06public\x12\x1c\n\x06\x63ustom\x18\x0b \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x63ustom\x12\x1c\n\x06vendor\x18\r \x01(\tB\x04\xe2\x41\x01\x03R\x06vendor\x12J\n\x11vendor_attributes\x18\x0e \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x03R\x10vendorAttributes\x12#\n\nsource_url\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\tsourceUrl\x12\x1e\n\x07version\x18\x10 \x01(\tB\x04\xe2\x41\x01\x03R\x07version\x12>\n\x05tasks\x18\x11 \x03(\x0b\x32\".vdp.pipeline.v1beta.ComponentTaskB\x04\xe2\x41\x01\x03R\x05tasks\x12&\n\x0b\x64\x65scription\x18\x12 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12`\n\rrelease_stage\x18\x13 \x01(\x0e\x32\x35.vdp.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage:b\xea\x41_\n$api.instill.tech/ConnectorDefinition\x12\x1a\x63onnector-definitions/{id}\x12\x1b\x63onnector-definitions/{uid}J\x04\x08\x0c\x10\r\"\xcd\x02\n\x0cOperatorSpec\x12V\n\x17\x63omponent_specification\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x02R\x16\x63omponentSpecification\x12p\n\x13\x64\x61ta_specifications\x18\x03 \x03(\x0b\x32\x39.vdp.pipeline.v1beta.OperatorSpec.DataSpecificationsEntryB\x04\xe2\x41\x01\x02R\x12\x64\x61taSpecifications\x1am\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12<\n\x05value\x18\x02 \x01(\x0b\x32&.vdp.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01J\x04\x08\x02\x10\x03\"\xd8\x05\n\x12OperatorDefinition\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12\x16\n\x03uid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid\x12\x14\n\x02id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x05R\x02id\x12\x1a\n\x05title\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x05title\x12\x31\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x64ocumentationUrl\x12\x18\n\x04icon\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x04icon\x12;\n\x04spec\x18\x07 \x01(\x0b\x32!.vdp.pipeline.v1beta.OperatorSpecB\x04\xe2\x41\x01\x03R\x04spec\x12\"\n\ttombstone\x18\x08 \x01(\x08\x42\x04\xe2\x41\x01\x03R\ttombstone\x12\x1c\n\x06public\x18\t \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06public\x12\x1c\n\x06\x63ustom\x18\n \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x63ustom\x12#\n\nsource_url\x18\x0f \x01(\tB\x04\xe2\x41\x01\x03R\tsourceUrl\x12\x1e\n\x07version\x18\x10 \x01(\tB\x04\xe2\x41\x01\x03R\x07version\x12>\n\x05tasks\x18\x11 \x03(\x0b\x32\".vdp.pipeline.v1beta.ComponentTaskB\x04\xe2\x41\x01\x03R\x05tasks\x12&\n\x0b\x64\x65scription\x18\x12 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12`\n\rrelease_stage\x18\x13 \x01(\x0e\x32\x35.vdp.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x04\xe2\x41\x01\x03R\x0creleaseStage:_\xea\x41\\\n#api.instill.tech/OperatorDefinition\x12\x19operator-definitions/{id}\x12\x1aoperator-definitions/{uid}J\x04\x08\x0b\x10\x0c\"\x8a\x02\n\x1fListComponentDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12L\n\x04view\x18\x03 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x01R\x04view\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x12\x1d\n\x04page\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x03R\x04page\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_viewB\t\n\x07_filterB\x07\n\x05_pageJ\x04\x08\x02\x10\x03\"\xd7\x01\n ListComponentDefinitionsResponse\x12]\n\x15\x63omponent_definitions\x18\x01 \x03(\x0b\x32(.vdp.pipeline.v1beta.ComponentDefinitionR\x14\x63omponentDefinitions\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x05 \x01(\x05R\x04pageJ\x04\x08\x02\x10\x03\"\x9b\x02\n\x1fListConnectorDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x12L\n\x04view\x18\x05 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x03R\x04view\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filterB\x07\n\x05_viewJ\x04\x08\x03\x10\x04\"\xc8\x01\n ListConnectorDefinitionsResponse\x12]\n\x15\x63onnector_definitions\x18\x01 \x03(\x0b\x32(.vdp.pipeline.v1beta.ConnectorDefinitionR\x14\x63onnectorDefinitions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xe1\x01\n\x1dGetConnectorDefinitionRequest\x12\x63\n\x04name\x18\x01 \x01(\tBO\x92\x41\x1f\xca>\x1c\xfa\x02\x19\x63onnector_definition_name\xe2\x41\x01\x02\xfa\x41&\n$api.instill.tech/ConnectorDefinitionR\x04name\x12L\n\x04view\x18\x03 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_viewJ\x04\x08\x02\x10\x03\"}\n\x1eGetConnectorDefinitionResponse\x12[\n\x14\x63onnector_definition\x18\x01 \x01(\x0b\x32(.vdp.pipeline.v1beta.ConnectorDefinitionR\x13\x63onnectorDefinition\"\x9a\x02\n\x1eListOperatorDefinitionsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x12L\n\x04view\x18\x05 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x03R\x04view\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filterB\x07\n\x05_viewJ\x04\x08\x03\x10\x04\"\xc4\x01\n\x1fListOperatorDefinitionsResponse\x12Z\n\x14operator_definitions\x18\x01 \x03(\x0b\x32\'.vdp.pipeline.v1beta.OperatorDefinitionR\x13operatorDefinitions\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\xde\x01\n\x1cGetOperatorDefinitionRequest\x12\x61\n\x04name\x18\x01 \x01(\tBM\x92\x41\x1e\xca>\x1b\xfa\x02\x18operator_definition_name\xe2\x41\x01\x02\xfa\x41%\n#api.instill.tech/OperatorDefinitionR\x04name\x12L\n\x04view\x18\x03 \x01(\x0e\x32-.vdp.pipeline.v1beta.ComponentDefinition.ViewB\x04\xe2\x41\x01\x01H\x00R\x04view\x88\x01\x01\x42\x07\n\x05_viewJ\x04\x08\x02\x10\x03\"y\n\x1dGetOperatorDefinitionResponse\x12X\n\x13operator_definition\x18\x01 \x01(\x0b\x32\'.vdp.pipeline.v1beta.OperatorDefinitionR\x12operatorDefinition*\xca\x01\n\rConnectorType\x12\x1e\n\x1a\x43ONNECTOR_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43ONNECTOR_TYPE_AI\x10\x03\x12\x17\n\x13\x43ONNECTOR_TYPE_DATA\x10\x05\x12\x1b\n\x17\x43ONNECTOR_TYPE_OPERATOR\x10\x06\x12\x1e\n\x1a\x43ONNECTOR_TYPE_APPLICATION\x10\x07\x12\x1a\n\x16\x43ONNECTOR_TYPE_GENERIC\x10\x08\"\x04\x08\x01\x10\x01\"\x04\x08\x02\x10\x02\"\x04\x08\x04\x10\x04\x42\xe7\x01\n\x17\x63om.vdp.pipeline.v1betaB\x18\x43omponentDefinitionProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.component_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\030ComponentDefinitionProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._options = None
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._serialized_options = b'\342A\001\002'
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._serialized_options = b'\342A\001\002'
  _COMPONENTDEFINITION.fields_by_name['name']._options = None
  _COMPONENTDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['uid']._options = None
  _COMPONENTDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['id']._options = None
  _COMPONENTDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _COMPONENTDEFINITION.fields_by_name['title']._options = None
  _COMPONENTDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['icon']._options = None
  _COMPONENTDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['spec']._options = None
  _COMPONENTDEFINITION.fields_by_name['spec']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['type']._options = None
  _COMPONENTDEFINITION.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['tombstone']._options = None
  _COMPONENTDEFINITION.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['public']._options = None
  _COMPONENTDEFINITION.fields_by_name['public']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['custom']._options = None
  _COMPONENTDEFINITION.fields_by_name['custom']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['vendor']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['source_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['source_url']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['version']._options = None
  _COMPONENTDEFINITION.fields_by_name['version']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['tasks']._options = None
  _COMPONENTDEFINITION.fields_by_name['tasks']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['description']._options = None
  _COMPONENTDEFINITION.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _COMPONENTDEFINITION.fields_by_name['release_stage']._options = None
  _COMPONENTDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _DATASPECIFICATION.fields_by_name['input']._options = None
  _DATASPECIFICATION.fields_by_name['input']._serialized_options = b'\342A\001\003'
  _DATASPECIFICATION.fields_by_name['output']._options = None
  _DATASPECIFICATION.fields_by_name['output']._serialized_options = b'\342A\001\003'
  _CONNECTORSPEC_DATASPECIFICATIONSENTRY._options = None
  _CONNECTORSPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _CONNECTORSPEC.fields_by_name['component_specification']._options = None
  _CONNECTORSPEC.fields_by_name['component_specification']._serialized_options = b'\342A\001\002'
  _CONNECTORSPEC.fields_by_name['data_specifications']._options = None
  _CONNECTORSPEC.fields_by_name['data_specifications']._serialized_options = b'\342A\001\002'
  _CONNECTORDEFINITION.fields_by_name['name']._options = None
  _CONNECTORDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['uid']._options = None
  _CONNECTORDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['id']._options = None
  _CONNECTORDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _CONNECTORDEFINITION.fields_by_name['title']._options = None
  _CONNECTORDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['documentation_url']._options = None
  _CONNECTORDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['icon']._options = None
  _CONNECTORDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['spec']._options = None
  _CONNECTORDEFINITION.fields_by_name['spec']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['type']._options = None
  _CONNECTORDEFINITION.fields_by_name['type']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['tombstone']._options = None
  _CONNECTORDEFINITION.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['public']._options = None
  _CONNECTORDEFINITION.fields_by_name['public']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['custom']._options = None
  _CONNECTORDEFINITION.fields_by_name['custom']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['vendor']._options = None
  _CONNECTORDEFINITION.fields_by_name['vendor']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['vendor_attributes']._options = None
  _CONNECTORDEFINITION.fields_by_name['vendor_attributes']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['source_url']._options = None
  _CONNECTORDEFINITION.fields_by_name['source_url']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['version']._options = None
  _CONNECTORDEFINITION.fields_by_name['version']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['tasks']._options = None
  _CONNECTORDEFINITION.fields_by_name['tasks']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['description']._options = None
  _CONNECTORDEFINITION.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION.fields_by_name['release_stage']._options = None
  _CONNECTORDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _CONNECTORDEFINITION._options = None
  _CONNECTORDEFINITION._serialized_options = b'\352A_\n$api.instill.tech/ConnectorDefinition\022\032connector-definitions/{id}\022\033connector-definitions/{uid}'
  _OPERATORSPEC_DATASPECIFICATIONSENTRY._options = None
  _OPERATORSPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _OPERATORSPEC.fields_by_name['component_specification']._options = None
  _OPERATORSPEC.fields_by_name['component_specification']._serialized_options = b'\342A\001\002'
  _OPERATORSPEC.fields_by_name['data_specifications']._options = None
  _OPERATORSPEC.fields_by_name['data_specifications']._serialized_options = b'\342A\001\002'
  _OPERATORDEFINITION.fields_by_name['name']._options = None
  _OPERATORDEFINITION.fields_by_name['name']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['uid']._options = None
  _OPERATORDEFINITION.fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['id']._options = None
  _OPERATORDEFINITION.fields_by_name['id']._serialized_options = b'\342A\001\005'
  _OPERATORDEFINITION.fields_by_name['title']._options = None
  _OPERATORDEFINITION.fields_by_name['title']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['documentation_url']._options = None
  _OPERATORDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['icon']._options = None
  _OPERATORDEFINITION.fields_by_name['icon']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['spec']._options = None
  _OPERATORDEFINITION.fields_by_name['spec']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['tombstone']._options = None
  _OPERATORDEFINITION.fields_by_name['tombstone']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['public']._options = None
  _OPERATORDEFINITION.fields_by_name['public']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['custom']._options = None
  _OPERATORDEFINITION.fields_by_name['custom']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['source_url']._options = None
  _OPERATORDEFINITION.fields_by_name['source_url']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['version']._options = None
  _OPERATORDEFINITION.fields_by_name['version']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['tasks']._options = None
  _OPERATORDEFINITION.fields_by_name['tasks']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['description']._options = None
  _OPERATORDEFINITION.fields_by_name['description']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION.fields_by_name['release_stage']._options = None
  _OPERATORDEFINITION.fields_by_name['release_stage']._serialized_options = b'\342A\001\003'
  _OPERATORDEFINITION._options = None
  _OPERATORDEFINITION._serialized_options = b'\352A\\\n#api.instill.tech/OperatorDefinition\022\031operator-definitions/{id}\022\032operator-definitions/{uid}'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTCONNECTORDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['name']._options = None
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\037\312>\034\372\002\031connector_definition_name\342A\001\002\372A&\n$api.instill.tech/ConnectorDefinition'
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['view']._options = None
  _GETCONNECTORDEFINITIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTOPERATORDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['name']._options = None
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['name']._serialized_options = b'\222A\036\312>\033\372\002\030operator_definition_name\342A\001\002\372A%\n#api.instill.tech/OperatorDefinition'
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['view']._options = None
  _GETOPERATORDEFINITIONREQUEST.fields_by_name['view']._serialized_options = b'\342A\001\001'
  _globals['_CONNECTORTYPE']._serialized_start=6246
  _globals['_CONNECTORTYPE']._serialized_end=6448
  _globals['_COMPONENTDEFINITION']._serialized_start=244
  _globals['_COMPONENTDEFINITION']._serialized_end=1636
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_start=1053
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_end=1384
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_start=1275
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_end=1384
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_start=1386
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_end=1445
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_start=1448
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_end=1636
  _globals['_DATASPECIFICATION']._serialized_start=1638
  _globals['_DATASPECIFICATION']._serialized_end=1765
  _globals['_CONNECTORSPEC']._serialized_start=1768
  _globals['_CONNECTORSPEC']._serialized_end=2109
  _globals['_CONNECTORSPEC_DATASPECIFICATIONSENTRY']._serialized_start=1275
  _globals['_CONNECTORSPEC_DATASPECIFICATIONSENTRY']._serialized_end=1384
  _globals['_CONNECTORDEFINITION']._serialized_start=2112
  _globals['_CONNECTORDEFINITION']._serialized_end=3013
  _globals['_OPERATORSPEC']._serialized_start=3016
  _globals['_OPERATORSPEC']._serialized_end=3349
  _globals['_OPERATORSPEC_DATASPECIFICATIONSENTRY']._serialized_start=1275
  _globals['_OPERATORSPEC_DATASPECIFICATIONSENTRY']._serialized_end=1384
  _globals['_OPERATORDEFINITION']._serialized_start=3352
  _globals['_OPERATORDEFINITION']._serialized_end=4080
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_start=4083
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_end=4349
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_start=4352
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_end=4567
  _globals['_LISTCONNECTORDEFINITIONSREQUEST']._serialized_start=4570
  _globals['_LISTCONNECTORDEFINITIONSREQUEST']._serialized_end=4853
  _globals['_LISTCONNECTORDEFINITIONSRESPONSE']._serialized_start=4856
  _globals['_LISTCONNECTORDEFINITIONSRESPONSE']._serialized_end=5056
  _globals['_GETCONNECTORDEFINITIONREQUEST']._serialized_start=5059
  _globals['_GETCONNECTORDEFINITIONREQUEST']._serialized_end=5284
  _globals['_GETCONNECTORDEFINITIONRESPONSE']._serialized_start=5286
  _globals['_GETCONNECTORDEFINITIONRESPONSE']._serialized_end=5411
  _globals['_LISTOPERATORDEFINITIONSREQUEST']._serialized_start=5414
  _globals['_LISTOPERATORDEFINITIONSREQUEST']._serialized_end=5696
  _globals['_LISTOPERATORDEFINITIONSRESPONSE']._serialized_start=5699
  _globals['_LISTOPERATORDEFINITIONSRESPONSE']._serialized_end=5895
  _globals['_GETOPERATORDEFINITIONREQUEST']._serialized_start=5898
  _globals['_GETOPERATORDEFINITIONREQUEST']._serialized_end=6120
  _globals['_GETOPERATORDEFINITIONRESPONSE']._serialized_start=6122
  _globals['_GETOPERATORDEFINITIONRESPONSE']._serialized_end=6243
# @@protoc_insertion_point(module_scope)
